Flask-mwoauth is an open-source project, released under the MIT license.
Contributions are very welcome, as pull requests on GitHub, or otherwise.

The following people have contributed to Flask-mwoauth (in alphabetical order):
  * Cristian Consonni (CristianCantoro)
  * Merlijn van Deen (valhallasw)
  * Jan Lebert (sitic)
  * Kunal Mehta (legoktm)
  * Yuvi Panda (yuvipanda)
  * Philip Tzou (philiptzou)
